@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * display.cc -
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1132,10 +1132,9 @@ GTKChapDisp::getVerseBefore(SWModule &imodule)
 		num = main_format_number(key->getVerse());
 		buf = g_strdup_printf(
 		    (settings.showversenum
-			 ? "&nbsp; <a name=\"%d\" href=\"sword:///%s\">"
-			   "<font size=\"%+d\" color=\"%s\">%s%s%s%s%s%s%s</font></a>&nbsp;"
-			 : "&nbsp; <a name=\"%d\"> </a>"),
-		    0,
+			 ? "&nbsp; <a name=\"0\" href=\"sword:///%s\">"
+			   "<font size=\"%+d\" color=\"%s\">%s%s%s%s%s%s%s</font>&nbsp;"
+			 : "&nbsp; <a name=\"0\"> </a>"),
 		    (char *)key->getText(),
 		    (settings.versestyle
 			 ? settings.verse_num_font_size + settings.base_font_size
@@ -1148,10 +1147,12 @@ GTKChapDisp::getVerseBefore(SWModule &imodule)
 
 		num = main_format_number(chapter);
 		buf = g_strdup_printf(
-		    "%s%s<br/><a name=\"TOP\"></a><hr/><div style=\"text-align: center\"><b>%s %s</b></div>",
+		    "<font color=\"%s\">%s</font>%s%s<br/><a name=\"TOP\"></a><hr/><div style=\"text-align: center\"><b>%s %s</b></div>",
+		    settings.bible_text_color,
 		    (strongs_or_morph
 			 ? block_render(imodule.renderText().c_str())
 			 : imodule.renderText().c_str()),
+		    (settings.showversenum ? "</a>" : ""),
 		    // extra break when excess strongs/morph space.
 		    (strongs_or_morph ? "<br/>" : ""),
 		    _("Chapter"), num);
@@ -1251,10 +1252,9 @@ GTKChapDisp::getVerseAfter(SWModule &imodule)
 		num = main_format_number(key->getVerse());
 		buf = g_strdup_printf(
 		    (settings.showversenum
-			 ? "&nbsp; <a name=\"%d\" href=\"sword:///%s\">"
-			   "<font size=\"%+d\" color=\"%s\">%s%s%s%s%s%s%s</font></a>&nbsp;"
-			 : "&nbsp; <a name=\"%d\"> </a>"),
-		    0,
+			 ? "&nbsp; <a name=\"0\" href=\"sword:///%s\">"
+			   "<font size=\"%+d\" color=\"%s\">%s%s%s%s%s%s%s</font>&nbsp;"
+			 : "&nbsp; <a name=\"0\"> </a>"),
 		    (char *)key->getText(),
 		    (settings.versestyle
 			 ? settings.verse_num_font_size + settings.base_font_size
@@ -1269,10 +1269,14 @@ GTKChapDisp::getVerseAfter(SWModule &imodule)
 			set_morph_order(imodule);
 		set_render_numbers(imodule, ops);
 
-		swbuf.append((strongs_or_morph
-				  ? block_render(imodule.renderText().c_str())
-				  : imodule.renderText().c_str()));
-		swbuf.append("</div>");
+		buf = g_strdup_printf("<font color=\"%s\">%s</font>%s</div>",
+				      settings.bible_text_color,
+				      (strongs_or_morph
+				       ? block_render(imodule.renderText().c_str())
+				       : imodule.renderText().c_str()),
+				      (settings.showversenum ? "</a>" : ""));
+		swbuf.append(buf);
+		g_free(buf);
 	}
 }
 
